@@ -15,11 +15,11 @@
 #' method without iterations.
 #'
 #' @return A list with: \itemize{
-#'    \item{A data frame containing data grouped by circulation weather types ("grouped_data").}
-#'    \item{An integer with the circulation weather types ("clas").}
-#'    \item{A data frame containing the number and percentage of days assigned to each weather type ("cwt_freq").}
-#'    \item{A data frame containing the number of days assigned to each weather type by month ("monthly_freq").}
-#'    \item{A data frame containing the number of days assigned to each weather type by year ("annual_freq").}
+#'    \item{A data frame containing data grouped by circulation types ("grouped_data").}
+#'    \item{An integer with the circulation types ("clas").}
+#'    \item{A data frame containing the number and percentage of days assigned to each circulation type ("ct_freq").}
+#'    \item{A data frame containing the number of days assigned to each circulation type by month ("monthly_freq").}
+#'    \item{A data frame containing the number of days assigned to each circulation type by year ("annual_freq").}
 #'    \item{The 'rotated' loadings matrix of class \code{"loadings"} ("rotated_loadings").}
 #'    \item{The scores of the supplied data on the principal components ("scores").}
 #'    \item{The coordinates of the scores used to perform the k-means clustering. For more information, read Esteban et al. (2005)("scores_coordinates").}
@@ -87,35 +87,35 @@ synoptclas <- function(smode_data, ncomp, extreme_scores = 2) {
         perc[ii] <- sum(clas$cluster == ii)/sum(clas$cluster != 0) * 100
     }
 
-    cwt_total_frequency <- rbind.data.frame(count, perc)
-    colnames(cwt_total_frequency) <- paste0("cl", 1:length(count))
-    rownames(cwt_total_frequency) <- c("counts", "percent")
+    ct_total_frequency <- rbind.data.frame(count, perc)
+    colnames(ct_total_frequency) <- paste0("cl", 1:length(count))
+    rownames(ct_total_frequency) <- c("counts", "percent")
 
     dates <- as.Date(rownames(smode_data))
     months <- format(as.Date(dates), "%m")
     years <- format(as.Date(dates), "%Y")
 
-    # creating dataframe of monthly frequencies per CWT
+    # creating dataframe of monthly frequencies per CT
     histo_month <- raster::aggregate(clas$cluster, by = list(Month = format(dates, "%m"), clas$cluster),
         sum, na.rm = TRUE)
     monthly_frequency <- histo_month[, 3]/histo_month[, 2]
     histo_month[, 3] <- NULL
     histo_month$frequency <- monthly_frequency
-    colnames(histo_month) <- c("Month", "CWT", "Counts")
+    colnames(histo_month) <- c("Month", "CT", "Counts")
 
-    # creating dataframe of yearly frequencies per CWT
+    # creating dataframe of yearly frequencies per CT
     histo_annual <- raster::aggregate(clas$cluster, by = list(Year = format(dates, "%Y"), clas$cluster),
         sum, na.rm = TRUE)
     annual_frequency <- histo_annual[, 3]/histo_annual[, 2]
     histo_annual[, 3] <- NULL
     histo_annual$frequency <- annual_frequency
-    colnames(histo_annual) <- c("Year", "CWT", "Counts")
+    colnames(histo_annual) <- c("Year", "CT", "Counts")
 
-    # Binding dates, CWT and data to plot after
+    # Binding dates, CT and data to plot after
     final_data <- cbind.data.frame(dates, clas$cluster, smode_data)
-    colnames(final_data)[2] <- "CWT"
+    colnames(final_data)[2] <- "CT"
 
-    return(list(grouped_data = final_data, clas = clas$cluster, cwt_freq = cwt_total_frequency,
+    return(list(grouped_data = final_data, clas = clas$cluster, ct_freq = ct_total_frequency,
         monthly_freq = histo_month, annual_freq = histo_annual, rotated_loadings = rotatedLoadings,
         scores = scores, scores_coordinates = coordinates_scores))
 
